Range-v3: ranges::v3::detail::set_symmetric_difference_cursor< IsConst, Rng1, Rng2, C, P1, P2 > Struct Template Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Public Types | Public Member Functions | List of all members
ranges::v3::detail::set_symmetric_difference_cursor< IsConst, Rng1, Rng2, C, P1, P2 > Struct Template Reference

## Public Types
using | reference_type = common_reference_t< range_reference_t< R1 >, range_reference_t< R2 > >
using | rvalue_reference_type = common_reference_t< range_rvalue_reference_t< R1 >, range_rvalue_reference_t< R2 > >
using | single_pass = meta::strict_or< SinglePass< iterator_t< R1 > >, SinglePass< iterator_t< R2 > >>
using | value_type = common_type_t< range_value_type_t< R1 >, range_value_type_t< R2 > >

## Public Member Functions
bool | equal (set_symmetric_difference_cursor const &that) const
bool | equal (default_sentinel) const
rvalue_reference_type | move () const noexcept(noexcept(iter_move(it1_)) &&noexcept(iter_move(it2_)))
void | next ()
reference_type | read () const noexcept(noexcept(*it1_) &&noexcept(*it2_))
| set_symmetric_difference_cursor (pred_ref_ pred, proj1_ref_ proj1, proj2_ref_ proj2, iterator_t< R1 > it1, sentinel_t< R1 > end1, iterator_t< R2 > it2, sentinel_t< R2 > end2)